User interface — SoL 4 user manual

# User interface

I tried to keep the user interaction as simple as possible, focused on the typical workflow of managing a new tourney: given a club, selected the championship, create a new tourney and then

1. insert the participants, selecting among known players, possibly organizing them in teams

   Note

   When the number of participants is odd, SoL will automatically handle the presence of a phantom player, against whom any player wins with a score of 25—0 (for this reason the scorecards for these imaginary matches are not even emitted). In particular cases the actual score assigned to the player may be changed on the Insert and edit window.

2. print the initial individual Badges

3. create the first round: if the tourney is associated with a particular glicko rating it will be generated using the current rate of each player, otherwise using a random order; in any case, the tourney manager may manually adjust the combinations generated by the computer

4. print the Scorecards of the current round

5. let's play carrom!

6. collect compiled Scorecards and insert the resulting scores

7. compute the new ranking and print it if needed

8. verify what picky guys are telling, correct and repeat

9. if desired, let other people join in adding new participants, or let other leave

10. compute the next round and jump to point 4 until satisfied, or until all possible combinations are exhausted, whichever comes first

11. if desired, generate and play a final round to determine the top four places in the ranking

12. assign the bounties, print the ranking and the final Badges

- Authentication
  - Administrator and guest users
  - Ownership
  - Self registration
  - Reset password
- Basic entities
  - Filtering
  - Insert, delete and modify
  - Users management
  - Players management
  - Clubs management
  - Championships management
  - Tourneys management
  - Glicko ratings
  - Players rates
- Other windows
  - Countdown
  - Upload